```@meta
CurrentModule = BetaRegression
```

# API

The exported symbols from this package define its interface.
Some symbols from other packages are re-exported for convenience.
Fields of objects with composite types should not be accessed directly; the internals
of any given structure may change at any time and this would not be considered a breaking
change.

## Fitting a model

```@docs
BetaRegressionModel
fit
fit!
```

## Properties of a model

The following common functions are extended for beta regression models:
- `Link`: The model's link function
- `aic`: Akaike's information criterion for the model
- `aicc`: Model AIC corrected for small sample sizes
- `bic`: Bayesian information criterion for the model
- `coef`: The vector ``\boldsymbol{\beta}`` of regression coefficients
- `coefnames`: Names of the coefficients (for models fit with a formula and table)
- `coeftable`: Table of coefficient names, values, standard errors, z-values, and p-values
- `confint`: Confidence intervals for the coefficient estimates
- `deviance`: Model deviance
- `devresid`: Vector of deviance residuals
- `dof`: Degrees of freedom
- `dof_residual`: Residual degrees of freedom
- `fitted`: The vector ``\hat{\mathbf{y}}`` of fitted values from the model
- `informationmatrix`: Expected or observed Fisher information
- `linearpredictor`: The linear predictor vector ``\boldsymbol{\eta}``
- `loglikelihood`: Model log likelihood
- `modelmatrix`: The model matrix ``\mathbf{X}``
- `nobs`: Number of observations used to fit the model
- `offset`: Model offset, empty if the model was not fit with an offset
- `params`: All parameters from the model, including both ``\boldsymbol{\beta}`` and ``\phi``
- `precision`: The estimated precision parameter ``\phi``
- `predict`: Predict new response values given new observations
- `r2`/`r²`: Pseudo ``R^2``
- `residuals`: Vector of residuals
- `response`: The response vector ``\boldsymbol{y}``
- `responsename`: Name of the response variable (for models fit with a formula and table)
- `score`: Score vector
- `stderror`: Standard errors of the coefficient and precision parameter estimates
- `vcov`: Variance-covariance matrix
- `weights`: Model weights, empty if the model was not fit with weights

Note that for a model with ``p`` independent variables, the information and
variance-covariance matrices will have ``p + 1`` rows and columns, the last of which
corresponds to the precision term.
However, `coef` does _not_ include the precision term and will have length ``p``.

## Developer documentation

This section documents some functions that are _not_ user facing (and are thus not
exported) and may be removed at any time.
They're included here for the benefit of anyone looking to contribute to the package
and wondering how certain internals work.

```@docs
dmueta
initialize!
```
